@@ -7,17 +7,19 @@ from erioon.functions import (
     calculate_shard_number,
     get_shard_limit
 )
+from erioon.ops import cache_ops
+
 
 class InMemoryInsertOne:
     """
     InMemoryInsertOne class manages inserting single records efficiently into a sharded collection stored on storage.
 
     Key features:
-    - Initializes by loading existing shard data, index, logs, and ops counter from blobs.
+    - Initializes by loading existing shard data, index, and logs from blobs.
     - Preloads existing record IDs into memory for fast duplicate detection.
     - Manages shards based on a shard size limit, flushing full shards to blob storage.
     - Keeps an in-memory index mapping record IDs to shards, and flushes it to blob storage.
-    - Buffers insertions and flushes data, index, logs, and ops counter when a threshold is reached or explicitly called.
+    - Buffers insertions and flushes data, index, and logs when a threshold is reached or explicitly called.
     - Uses msgpack for efficient binary serialization of shard data.
     - Logs insertion operations with timestamps and metadata for auditing.
     - Automatically handles shard rollover when the current shard exceeds the size limit.
@@ -25,8 +27,9 @@ class InMemoryInsertOne:
     Intended usage:
     - Create an instance per user/database/collection/container combination.
     - Use add_record(record) to insert a new record; duplicates will raise an error.
-    - Periodically call flush_all() to persist data, logs, and counters.
+    - Periodically call flush_all() to persist data and logs.
     """
+
     def __init__(self, user_id, db, collection, container_url, flush_threshold=1):
         self.user_id = user_id
         self.db = db
@@ -38,12 +41,10 @@ class InMemoryInsertOne:
         self.shard_filename = self._get_shard_filename(self.shard_number)
         self.index_filename = f"{db}/{collection}/index.msgpack"
         self.logs_filename = f"{db}/{collection}/logs.msgpack"
-        self.ops_filename = f"{db}/{collection}/ops.msgpack"
 
         self.shard_records = self._load_blob(self.shard_filename, default=[])
         self.index_data = self._load_blob(self.index_filename, default={})
         self.logs_data = self._load_blob(self.logs_filename, default={})
-        self.ops_data = self._load_blob(self.ops_filename, default={})
 
         self.shard_limit = get_shard_limit(user_id, db, collection, container_url)
         self.insert_count_since_flush = 0
@@ -52,8 +53,6 @@ class InMemoryInsertOne:
         self.existing_ids = set()
         self._populate_existing_ids()
 
-        self.ops_accumulated_count = 0
-
     def _get_shard_filename(self, shard_num):
         return f"{self.db}/{self.collection}/{self.collection}_{shard_num}.msgpack"
 
@@ -91,17 +90,7 @@ class InMemoryInsertOne:
             )
             self.logs_data = {k: v for k, v in sorted_logs[:150]}
 
-        self.ops_accumulated_count += count
-
-    def _flush_ops_if_needed(self, force=False):
-        if force or self.ops_accumulated_count >= 100:
-            today = datetime.datetime.utcnow().date().isoformat()
-            self.ops_data[today] = self.ops_data.get(today, 0) + self.ops_accumulated_count
-            self.ops_accumulated_count = 0
-            self.flush_ops()
-
-    def flush_ops(self):
-        self._flush_blob(self.ops_filename, self.ops_data)
+        cache_ops(self.db, self.collection, self.container_url, count, "WO")
 
     def _populate_existing_ids(self):
         self.existing_ids = set()
@@ -136,7 +125,6 @@ class InMemoryInsertOne:
         self.flush_shard()
         self.flush_index()
         self.flush_logs()
-        self._flush_ops_if_needed(force=True)
 
     def flush_shard(self):
         self._flush_blob(self.shard_filename, self.shard_records)
