@@ -5,17 +5,19 @@ from io import BytesIO
 import msgpack
 from azure.storage.blob import ContainerClient
 from erioon.functions import get_shard_limit
+from erioon.ops import cache_ops
+
 
 class InMemoryInsertMany:
     """
     InMemoryInsertMany class manages inserting single records efficiently into a sharded collection stored on storage.
 
     Key features:
-    - Initializes by loading existing shard data, index, logs, and ops counter from blobs.
+    - Initializes by loading existing shard data, index, and logs from blobs.
     - Preloads existing record IDs into memory for fast duplicate detection.
     - Manages shards based on a shard size limit, flushing full shards to blob storage.
     - Keeps an in-memory index mapping record IDs to shards, and flushes it to blob storage.
-    - Buffers insertions and flushes data, index, logs, and ops counter when a threshold is reached or explicitly called.
+    - Buffers insertions and flushes data, index, and logs when a threshold is reached or explicitly called.
     - Uses msgpack for efficient binary serialization of shard data.
     - Logs insertion operations with timestamps and metadata for auditing.
     - Automatically handles shard rollover when the current shard exceeds the size limit.
@@ -23,9 +25,9 @@ class InMemoryInsertMany:
     Intended usage:
     - Create an instance per user/database/collection/container combination.
     - Use add_record(record) to insert a new record; duplicates will raise an error.
-    - Periodically call flush_all() to persist data, logs, and counters.
+    - Periodically call flush_all() to persist data and logs.
     """
-    
+
     def __init__(self, user_id, db, collection, container_url):
         self.user_id = user_id
         self.db = db
@@ -37,13 +39,11 @@ class InMemoryInsertMany:
         self.shard_filename = f"{db}/{collection}/{collection}_{self.shard_number}.msgpack"
         self.index_filename = f"{db}/{collection}/index.msgpack"
         self.logs_filename = f"{db}/{collection}/logs.msgpack"
-        self.ops_filename = f"{db}/{collection}/ops.msgpack"
         self.shard_limit = get_shard_limit(user_id, db, collection, container_url)
 
         self._load_shard()
         self._load_index()
         self._load_logs()
-        self._load_ops()
 
         self.existing_ids = set()
         self._initialize_existing_ids()
@@ -77,13 +77,6 @@ class InMemoryInsertMany:
         except Exception:
             self.logs_data = {}
 
-    def _load_ops(self):
-        blob_client = self.container_client.get_blob_client(self.ops_filename)
-        try:
-            self.ops_data = msgpack.unpackb(blob_client.download_blob().readall(), raw=False)
-        except Exception:
-            self.ops_data = {}
-
     def _initialize_existing_ids(self):
         self.existing_ids.clear()
         for rec in self.shard_records:
@@ -121,19 +114,7 @@ class InMemoryInsertMany:
             )
             self.logs_data = {k: v for k, v in sorted_logs[:150]}
 
-        self._update_ops_counter(count)
-
-    def _update_ops_counter(self, count):
-        today = datetime.datetime.utcnow().date().isoformat()
-        self.ops_data[today] = self.ops_data.get(today, 0) + count
-        self.flush_ops()
-
-    def flush_ops(self):
-        blob_client = self.container_client.get_blob_client(self.ops_filename)
-        with BytesIO() as buf:
-            buf.write(msgpack.packb(self.ops_data, use_bin_type=True))
-            buf.seek(0)
-            blob_client.upload_blob(buf, overwrite=True)
+        cache_ops(self.db, self.collection, self.container_url, count, "WM")
 
     def add_record(self, record):
         if len(self.shard_records) >= self.shard_limit:
@@ -153,7 +134,6 @@ class InMemoryInsertMany:
         self.flush_shard()
         self.flush_index()
         self.flush_logs()
-        self.flush_ops()
 
     def flush_shard(self):
         blob_client = self.container_client.get_blob_client(self.shard_filename)
