@@ -70,7 +70,7 @@ class Collection:
     # RESPONSE FOR ONLY WRITE
     def _read_only_response(self):
         """Standardized error response for blocked write operations."""
-        return "[Erioon Error - Database access denied] This user is not allowed to perform write operations in the selected collection."
+        print("[Erioon Error - Database access denied] This user is not allowed to perform write operations in the selected collection.")
 
     # GET ALL RECORDS OF A COLLECTION
     def get_all(self, limit=1000000):
