@@ -184,30 +184,6 @@ def is_duplicate_id(user_id_cont, database, collection, _id, container_url):
                 return True 
     return False
 
-# OPS COUNTER
-def update_ops_counter(database, collection, count, container_client):
-    """
-    Updates the operation count for the current UTC day in ops.msgpack.
-    """
-    from datetime import datetime
-
-    today = datetime.utcnow().date().isoformat()
-    ops_path = f"{database}/{collection}/ops.msgpack"
-    blob_client = container_client.get_blob_client(ops_path)
-
-    try:
-        existing_blob = blob_client.download_blob().readall()
-        ops_data = msgpack.unpackb(existing_blob, raw=False)
-    except Exception:
-        ops_data = {}
-
-    ops_data[today] = ops_data.get(today, 0) + count
-
-    with BytesIO() as buf:
-        buf.write(msgpack.packb(ops_data, use_bin_type=True))
-        buf.seek(0)
-        blob_client.upload_blob(buf, overwrite=True)
-
 # SAVE LOGS
 def save_logs(user_id_cont, database, collection, method, log_type, log_message, count, container_url):
     container_client = ContainerClient.from_container_url(container_url)
@@ -238,8 +214,6 @@ def save_logs(user_id_cont, database, collection, method, log_type, log_message,
         out_file.seek(0)
         logs_blob_client.upload_blob(out_file, overwrite=True)
 
-    update_ops_counter(database, collection, count, container_client)
-
 # ASYNC LOG SAVING
 def async_log(user_id, db, collection, method, status, message, count, container_url):
     """
