@@ -60,7 +60,7 @@ class Playbox:
         return self.cluster == "viewAccess"
 
     def _read_only_response(self):
-        return "[Erioon Error - Playbox access denied] This user is not allowed to perform any operations in the selected playbox."
+        print("[Erioon Error - Playbox access denied] This user is not allowed to perform any operations in the selected playbox.")
 
     def _print_header(self, message, style="bold magenta"):
         self.console.print(f"{message}", style=style)
